'use strict';

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var constants = require('../../helpers/imageServiceConstants');

var _require = require('../../helpers/imageServiceUtils'),
    isValidRequest = _require.isValidRequest;

var attributes = require('../../engines/attributes');

var transform = require('../transform');

var _require2 = require('../uri'),
    getURI = _require2.getURI;

var _require3 = require('../../helpers/imagePlaceholderUtils'),
    getScaledDimensions = _require3.getScaledDimensions,
    getBlurValue = _require3.getBlurValue,
    getCSSOverrides = _require3.getCSSOverrides,
    validateTargetDimensions = _require3.validateTargetDimensions,
    getIsFakeTile = _require3.getIsFakeTile,
    getConvertedFitting = _require3.getConvertedFitting;
/**
 * returns image _placeholder_ transform uri and the
 * needed css for alignment and positioning
 *
 * @param {string}                  fittingType imageServicesTypes.fittingTypes
 * @param {ImageTransformSource}    src         image
 * @param {ImageTransformTarget}    target      target dimensions
 * @param {ImagePlaceholderOptions} [options]   environment / transformation  options
 *
 * @returns {{uri: string, css: {img: {}, container: {}}} | {uri: string, attr: {img: {}, container: {}}} | {}}
 */


function getPlaceholder(fittingType, src, target, options) {
  if (options === void 0) {
    options = {};
  }

  if (!isValidRequest(fittingType, src, target)) {
    return constants.emptyData;
  }

  var newTarget = _objectSpread(_objectSpread({}, target), validateTargetDimensions(src, target));

  var alignment = target.alignment,
      htmlTag = target.htmlTag;
  var _options = options,
      isSEOBot = _options.isSEOBot;
  var isFakeTile = getIsFakeTile(fittingType, src, newTarget);
  var scaledDimensions = getScaledDimensions(fittingType, src, newTarget, isSEOBot);
  var blur = getBlurValue(newTarget.width, fittingType, isSEOBot);
  var convertedFittingType = getConvertedFitting(fittingType, isFakeTile);
  var overrideCSS = getCSSOverrides(fittingType, src, target, alignment);

  var _getData = getData(convertedFittingType, src, _objectSpread(_objectSpread({}, scaledDimensions), {}, {
    alignment: alignment,
    htmlTag: htmlTag
  }), {
    filters: {
      blur: blur
    }
  }),
      uri = _getData.uri;

  var _getData2 = getData(fittingType, src, _objectSpread(_objectSpread({}, newTarget), {}, {
    alignment: alignment,
    htmlTag: htmlTag
  })),
      _getData2$attr = _getData2.attr,
      attr = _getData2$attr === void 0 ? {} : _getData2$attr,
      css = _getData2.css;

  css.img = css.img || {};
  css.container = css.container || {};
  Object.assign(css.img, overrideCSS.img);
  Object.assign(css.container, overrideCSS.container);
  return {
    uri: uri,
    css: css,
    attr: attr
  };
}
/**
 * returns image transform uri and the
 * needed css for alignment and positioning
 *
 * @param {string}                  fittingType         imageServicesTypes.fittingTypes
 * @param {ImageTransformSource}    src                 source image
 * @param {ImageTransformTarget}    target              target component
 * @param {ImageTransformOptions}   [options]          transform options
 *
 * @returns {{uri: string, css: {img: {}, container: {}}} | {uri: string, attr: {img: {}, container: {}}} | {}}
 */


function getData(fittingType, src, target, options) {
  var data = {}; // check if valid request

  if (isValidRequest(fittingType, src, target)) {
    // handle site BG legacy fitting types if needed
    var targetObj = transform.getTarget(fittingType, src, target); // parse request and create working OBJ

    var transformObj = transform.getTransform(fittingType, src, targetObj, options);
    data.uri = getURI(fittingType, src, targetObj, options, transformObj); //set the CSS or the SVG property

    Object.assign(data, attributes.getAttributes(transformObj, targetObj));
  } else {
    // empty data
    data = constants.emptyData;
  } // return data to be used in html


  return data;
}

module.exports.getData = getData;
module.exports.getPlaceholder = getPlaceholder;
//# sourceMappingURL=api.js.map