'use strict';

var _require = require('../helpers/imageServiceConstants'),
    htmlTag = _require.htmlTag;

var _require2 = require('../helpers/browserFeatureSupport'),
    isObjectFitBrowserSupport = _require2.isObjectFitBrowserSupport;

var backgroundAttributes = require('../engines/attributes/backgroundAttributes');

var imgAttributes = require('../engines/attributes/imgAttributes');

var SVGAttributes = require('../engines/attributes/SVGAttributes');

var imgPolyfillAttributes = require('../engines/attributes/imgPolyfillAttributes');
/**
 * get CSS or SVG attributes to be used in the browser
 * @param {object}                  transformsObj    transform parts object
 * @param {ImageTransformTarget}    target
 *
 * @returns object
 */


function getAttributes(transformsObj, target) {
  var attributesGetter;

  if (target.htmlTag === htmlTag.BG) {
    attributesGetter = backgroundAttributes;
  } else if (target.htmlTag === htmlTag.SVG) {
    attributesGetter = SVGAttributes;
  } else if (isObjectFitBrowserSupport()) {
    attributesGetter = imgAttributes;
  } else {
    attributesGetter = imgPolyfillAttributes;
  }

  return attributesGetter.get(transformsObj, target);
}

module.exports.getAttributes = getAttributes;
//# sourceMappingURL=attributes.js.map